/* This is the main window for our precision test.
 * It inherits from the QMainDialog class.
 * 
 * concept and design: Petr Felkel - felkepet@fel.cvut.cz
 *
 * programming: Petr Felkel - felkepet@fel.cvut.cz
 *				Lukas Novosad - novosluk@fel.cvut.cz
 *
 * date: 21.10.2010
 *
 */

#include "exercise_2.h"

exercise_2::exercise_2(QWidget *parent, Qt::WFlags flags)
	: QMainWindow(parent, flags)
{
	ui.setupUi(this);
	drawArea.setParent(ui.drawAreaWidget);
	
	// show an initial message on the QStatusBar of the QMainWindow
	ui.statusBar->showMessage(QString("Demonstration of Convex Hull Algorithms "));
	
	// Qt connect statements
	QObject::connect(this, SIGNAL(pointGeneratorChanged(PointGenerator)), &drawArea, SLOT(setPointGenerator(PointGenerator))	);
	QObject::connect(this, SIGNAL(chAlgorithmChanged(ChAlgorithm)),	 	  &drawArea, SLOT(setChAlgorithm(ChAlgorithm))			);
	QObject::connect(this, SIGNAL(numOfPointsChanged(long)),	 		  &drawArea, SLOT(setNumberOfPoints(long))				);
	QObject::connect(&drawArea, SIGNAL(statusBarMessageChanged(QString)), ui.statusBar, SLOT(showMessage(QString))				);
}


exercise_2::~exercise_2()
{

}


/*
 * This method shows the about dialog.
 */
void exercise_2::createAboutDialog(void)
{
	aboutDialog.setModal(true);
	aboutDialog.show();
}

// slots to select the point generator
void exercise_2::setPointGeneratorInDisc()		{	ui.rb_In_Disc_3->setChecked(true); 		emit pointGeneratorChanged(IN_DISC);		}
void exercise_2::setPointGeneratorOnCircle()	{	ui.rb_On_Circle_3->setChecked(true); 	emit pointGeneratorChanged(ON_CIRCLE);		}
void exercise_2::setPointGeneratorInSquare()	{	ui.rb_In_Square_3->setChecked(true); 	emit pointGeneratorChanged(IN_SQUARE);		}
void exercise_2::setPointGeneratorOnSquare()	{	ui.rb_On_Square_3->setChecked(true); 	emit pointGeneratorChanged(ON_SQUARE);		}
void exercise_2::setPointGeneratorInRectangle()	{	ui.rb_In_Rectangle_3->setChecked(true);	emit pointGeneratorChanged(IN_RECTANGLE);	}
void exercise_2::setPointGeneratorOnSegment()	{	ui.rb_On_Segment_3->setChecked(true); 	emit pointGeneratorChanged(ON_SEGMENT);		}

// slots to select the CH algorithm
void exercise_2::setChAlg_AKL()				{	ui.rb_ch_Akl_4->setChecked(true);			emit chAlgorithmChanged( AKL );				}
void exercise_2::setChAlg_BYKAT()			{	ui.rb_ch_Bykat_4->setChecked(true);			emit chAlgorithmChanged( BYKAT );			}
void exercise_2::setChAlg_EDDY()			{	ui.rb_ch_Eddy_4->setChecked(true);			emit chAlgorithmChanged( EDDY );			}
void exercise_2::setChAlg_GRAHAM_ANDREW()	{	ui.rb_ch_GrahamAndrew_4->setChecked(true);	emit chAlgorithmChanged( GRAHAM_ANDREW );	}
void exercise_2::setChAlg_JARVIS()			{	ui.rb_ch_Jarvis_4->setChecked(true);		emit chAlgorithmChanged( JARVIS );			}
void exercise_2::setChAlg_MY_GRAHAM()		{	ui.rb_ch_My_Graham_4->setChecked(true);		emit chAlgorithmChanged( MY_GRAHAM );		}
void exercise_2::setChAlg_MY_JARVIS()		{	ui.rb_ch_My_Jarvis_4->setChecked(true);		emit chAlgorithmChanged( MY_JARVIS );		}

// slots to select the number of points
void exercise_2::setNumOfPoints10()			{	ui.rb_10->setChecked(true);			emit numOfPointsChanged( 10);		}
void exercise_2::setNumOfPoints100()		{	ui.rb_100->setChecked(true);		emit numOfPointsChanged( 100);		}
void exercise_2::setNumOfPoints1000()		{	ui.rb_1000->setChecked(true);		emit numOfPointsChanged( 1000);		}
void exercise_2::setNumOfPoints10000()		{	ui.rb_10000->setChecked(true);		emit numOfPointsChanged( 10000);	}
void exercise_2::setNumOfPoints100000()		{	ui.rb_100000->setChecked(true);		emit numOfPointsChanged( 100000);	}
void exercise_2::setNumOfPoints1000000()	{	ui.rb_1000000->setChecked(true);	emit numOfPointsChanged( 1000000);	}
void exercise_2::setNumOfPoints10000000()	{	ui.rb_10000000->setChecked(true);	emit numOfPointsChanged( 10000000);	}